@@ -1,12 +1,15 @@
+import abc
 import itertools
 import logging
 import os
+import pkg_resources
 import re
 import socket
 import subprocess
 import time
 import zlib
 from typing import List, Iterator, Optional, Tuple
+from urllib.parse import urljoin
 
 import bson
 import confluent_kafka
@@ -15,11 +18,15 @@ from confluent_kafka.cimpl import (  # pylint: disable=no-name-in-module
     KafkaException,
 )
 
-from ._api.models import Locus, _LocusSchema
+from ._api.api import _get_resource
+from ._api.models import _ClientConfigStreamingSchema, Locus, _LocusSchema
 from .exceptions import AntaresException
+from .config import config
 
 log = logging.getLogger(__name__)
 
+Topic = str
+
 
 class AntaresNetworkingException(AntaresException):
     pass
@@ -29,16 +36,81 @@ class AntaresAlertParseException(AntaresException):
     pass
 
 
-class StreamingClient:
-    _DEFAULT_CONFIG = {
-        "host": "pkc-epgnk.us-central1.gcp.confluent.cloud",
-        "port": 9092,
-    }
-    _POLLING_FREQUENCY: float = 1.0
-
-    def __init__(self, topics: List[str], **config):
+class AbstractStreamingClient(abc.ABC):
+    @abc.abstractmethod
+    def poll(
+        self, timeout: Optional[float] = None
+    ) -> Tuple[Tuple[None, None], Tuple[Topic, Locus]]:
         """
-        Creates a new ``StreamingClient`` instance.
+        Retrieve a single alert. This method blocks until ``timeout`` seconds have
+        elapsed (by default, an infinite amount of time).
+
+        Parameters
+        ----------
+        timeout: int
+            Number of seconds to block waiting for an alert. If None, block indefinitely
+            (default, None).
+
+        Returns
+        ----------
+        (topic, locus): (str, Locus)
+            Or ``(None, None)`` if ``timeout`` seconds elapse with no response
+        """
+        raise NotImplementedError
+
+    def iter(self, limit: Optional[int] = None) -> Iterator[Tuple[Topic, Locus]]:
+        """
+        Yield from ANTARES alert streams.
+
+        Parameters
+        -----------
+        limit: int
+            Maximum number of messages to yield. If None, yield
+            indefinitely (default, None).
+
+        Yields
+        ----------
+        (topic, locus): str, Locus
+
+        """
+        for i in itertools.count(start=1, step=1):
+            yield self.poll()
+            if limit and i >= limit:
+                return
+
+    @abc.abstractmethod
+    def commit(self):
+        raise NotImplementedError
+
+    @abc.abstractmethod
+    def close(self):
+        raise NotImplementedError
+
+    @abc.abstractmethod
+    def __enter__(self):
+        raise NotImplementedError
+
+    @abc.abstractmethod
+    def __exit__(self, exc_type, exc_val, exc_tb):
+        raise NotImplementedError
+
+
+class KafkaStreamingClient(AbstractStreamingClient):
+    _POLLING_FREQUENCY: float = 1.0
+    _TOPIC_PREFIX = "client."
+    _DEFAULT_SSL_CA_LOCATION: str = pkg_resources.resource_filename(
+        __name__, os.path.join("certificates", "kafka-ca.pem")
+    )
+
+    def fetch_config(self):
+        return _get_resource(
+            urljoin(config["ANTARES_API_BASE_URL"], "client/config/streaming/default"),
+            _ClientConfigStreamingSchema,
+        )
+
+    def __init__(self, topics: List[str], api_key: str, api_secret: str, **kwargs):
+        """
+        Creates a new ``KafkaStreamingClient`` instance.
 
         Parameters
         ----------
@@ -59,50 +131,25 @@ class StreamingClient:
             (default, True).
         """
         self._topics = topics
-        config = _merge_dictionaries(self._DEFAULT_CONFIG, config)
+        default_config = self.fetch_config()["options"]
         kafka_config = {
-            "bootstrap.servers": "{}:{}".format(config["host"], config["port"]),
-            "group.id": config.get("group", socket.gethostname()),
+            "group.id": kwargs.get("group", socket.gethostname()),
+            "logger": log,
             "default.topic.config": {"auto.offset.reset": "smallest"},
             "api.version.request": True,
             "broker.version.fallback": "0.10.0.0",
             "api.version.fallback.ms": 0,
-            "enable.auto.commit": config.get("enable_auto_commit", True),
-            "logger": log,
+            "enable.auto.commit": kwargs.get("enable_auto_commit", True),
+            "sasl.username": api_key,
+            "sasl.password": api_secret,
+            "ssl.ca.location": kwargs.get("ssl_ca_location")
+            or self._DEFAULT_SSL_CA_LOCATION,
+            **default_config,
         }
-        if "api_key" in config and "api_secret" in config:
-            kafka_config.update(
-                {
-                    "security.protocol": "SASL_SSL",
-                    "sasl.username": config["api_key"],
-                    "sasl.password": config["api_secret"],
-                    "sasl.mechanisms": "PLAIN",
-                    "ssl.ca.location": config.get("ssl_ca_location")
-                    or _locate_ssl_certs_file(),
-                }
-            )
         self._consumer = confluent_kafka.Consumer(kafka_config)
-        self._consumer.subscribe(self.topics)
-
-    def iter(self, limit: Optional[int] = None) -> Iterator[Tuple[str, Locus]]:
-        """
-        Yield from ANTARES alert streams.
-
-        Parameters
-        -----------
-        limit: int
-            Maximum number of messages to yield. If None, yield
-            indefinitely (default, None).
-
-        Yields
-        ----------
-        (topic, locus): str, Locus
-
-        """
-        for i in itertools.count(start=1, step=1):
-            yield self.poll()
-            if limit and i >= limit:
-                return
+        self._consumer.subscribe(
+            [f"{self._TOPIC_PREFIX}{topic}" for topic in self.topics]
+        )
 
     def _timed_poll(self, timeout: float) -> Tuple[Optional[str], Optional[Locus]]:
         start_time = time.perf_counter()
@@ -244,3 +291,6 @@ def _parse_message(message):
         bson.loads(zlib.decompress(message.value()))
     )
     return locus
+
+
+StreamingClient = KafkaStreamingClient
